@@ -558,11 +558,8 @@ where
                                     let key = if i.sym.contains('-') {
                                         PropName::Str(Str {
                                             span: i.span,
+                                            raw: None,
                                             value: i.sym,
-                                            has_escape: false,
-                                            kind: StrKind::Normal {
-                                                contains_quote: false,
-                                            },
                                         })
                                     } else {
                                         PropName::Ident(i)
@@ -592,11 +589,11 @@ where
                                         None => true.into(),
                                     };
 
+                                    let str_value = format!("{}:{}", ns.sym, name.sym);
                                     let key = Str {
                                         span,
-                                        value: format!("{}:{}", ns.sym, name.sym).into(),
-                                        has_escape: false,
-                                        kind: Default::default(),
+                                        raw: None,
+                                        value: str_value.into(),
                                     };
                                     let key = PropName::Str(key);
 
@@ -721,12 +718,13 @@ where
         Some(match c {
             JSXElementChild::JSXText(text) => {
                 // TODO(kdy1): Optimize
+                let value = jsx_text_to_str(text.value);
                 let s = Str {
                     span: text.span,
-                    has_escape: text.raw != text.value,
-                    value: jsx_text_to_str(text.value),
-                    kind: Default::default(),
+                    raw: None,
+                    value,
                 };
+
                 if s.value.is_empty() {
                     return None;
                 }
@@ -878,12 +876,15 @@ where
         let value = a
             .value
             .map(|v| match v {
-                JSXAttrValue::Lit(Lit::Str(s)) => Box::new(Expr::Lit(Lit::Str(Str {
-                    span: s.span,
-                    value: transform_jsx_attr_str(&s.value).into(),
-                    has_escape: false,
-                    kind: Default::default(),
-                }))),
+                JSXAttrValue::Lit(Lit::Str(s)) => {
+                    let value = transform_jsx_attr_str(&s.value);
+
+                    Box::new(Expr::Lit(Lit::Str(Str {
+                        span: s.span,
+                        raw: None,
+                        value: value.into(),
+                    })))
+                }
                 JSXAttrValue::JSXExprContainer(JSXExprContainer {
                     expr: JSXExpr::Expr(e),
                     ..
@@ -1042,9 +1043,8 @@ where
                         specifiers: vec![specifier],
                         src: Str {
                             span: DUMMY_SP,
+                            raw: None,
                             value: "react".into(),
-                            has_escape: false,
-                            kind: Default::default(),
                         },
                         type_only: Default::default(),
                         asserts: Default::default(),
@@ -1109,6 +1109,9 @@ where
                 } else {
                     "jsx-runtime"
                 };
+
+                let value = format!("{}/{}", self.import_source, jsx_runtime);
+
                 prepend(
                     &mut module.body,
                     ModuleItem::ModuleDecl(ModuleDecl::Import(ImportDecl {
@@ -1116,9 +1119,8 @@ where
                         specifiers: imports,
                         src: Str {
                             span: DUMMY_SP,
-                            value: format!("{}/{}", self.import_source, jsx_runtime).into(),
-                            has_escape: false,
-                            kind: Default::default(),
+                            raw: None,
+                            value: value.into(),
                         },
                         type_only: Default::default(),
                         asserts: Default::default(),
@@ -1145,11 +1147,8 @@ where
                 if i.as_ref().starts_with(|c: char| c.is_ascii_lowercase()) {
                     Box::new(Expr::Lit(Lit::Str(Str {
                         span,
+                        raw: None,
                         value: i.sym,
-                        has_escape: false,
-                        kind: StrKind::Normal {
-                            contains_quote: false,
-                        },
                     })))
                 } else {
                     Box::new(Expr::Ident(i))
@@ -1169,11 +1168,13 @@ where
                             .emit()
                     });
                 }
+
+                let value = format!("{}:{}", ns.sym, name.sym);
+
                 Box::new(Expr::Lit(Lit::Str(Str {
                     span,
-                    value: format!("{}:{}", ns.sym, name.sym).into(),
-                    has_escape: false,
-                    kind: Default::default(),
+                    raw: None,
+                    value: value.into(),
                 })))
             }
             JSXElementName::JSXMemberExpr(JSXMemberExpr { obj, prop }) => {
@@ -1214,22 +1215,22 @@ fn to_prop_name(n: JSXAttrName) -> PropName {
             if i.sym.contains('-') {
                 PropName::Str(Str {
                     span,
+                    raw: None,
                     value: i.sym,
-                    has_escape: false,
-                    kind: StrKind::Normal {
-                        contains_quote: false,
-                    },
                 })
             } else {
                 PropName::Ident(i)
             }
         }
-        JSXAttrName::JSXNamespacedName(JSXNamespacedName { ns, name }) => PropName::Str(Str {
-            span,
-            value: format!("{}:{}", ns.sym, name.sym).into(),
-            has_escape: false,
-            kind: Default::default(),
-        }),
+        JSXAttrName::JSXNamespacedName(JSXNamespacedName { ns, name }) => {
+            let value = format!("{}:{}", ns.sym, name.sym);
+
+            PropName::Str(Str {
+                span,
+                raw: None,
+                value: value.into(),
+            })
+        }
     }
 }
 
@@ -1268,12 +1269,15 @@ fn jsx_text_to_str(t: JsWord) -> JsWord {
 
 fn jsx_attr_value_to_expr(v: JSXAttrValue) -> Option<Box<Expr>> {
     Some(match v {
-        JSXAttrValue::Lit(Lit::Str(s)) => Box::new(Expr::Lit(Lit::Str(Str {
-            span: s.span,
-            value: transform_jsx_attr_str(&s.value).into(),
-            has_escape: false,
-            kind: Default::default(),
-        }))),
+        JSXAttrValue::Lit(Lit::Str(s)) => {
+            let value = transform_jsx_attr_str(&s.value);
+
+            Box::new(Expr::Lit(Lit::Str(Str {
+                span: s.span,
+                raw: None,
+                value: value.into(),
+            })))
+        }
         JSXAttrValue::Lit(lit) => Box::new(lit.into()),
         JSXAttrValue::JSXExprContainer(e) => match e.expr {
             JSXExpr::JSXEmptyExpr(_) => None?,
